@@ -1,16 +1,18 @@
 """The main file."""
 import json
 import re
+import webbrowser
 from datetime import datetime, timezone
-from distutils.version import LooseVersion
 from typing import List
 from urllib.parse import quote
 
 import bs4
 import humanize
+import questionary
 import requests
 import rich
 import typer
+from packaging.version import parse as parse_version
 from rich.console import Console
 from rich.markdown import Markdown
 from rich.panel import Panel
@@ -23,6 +25,14 @@ from typer import Argument, Option
 # We instantiate a typer app and a rich console for later use
 app = typer.Typer(add_completion=False)
 console = Console(theme=Theme({"markdown.link": "#6088ff"}))
+# We will use this styling in the browse command
+link_style = questionary.Style(
+    [
+        ("name", "bold red"),
+        ("seperator", "gray"),
+        ("url", "cyan"),
+    ]
+)
 # We will use these headers for every request
 headers = {"User-Agent": "wasi_master/pypi_cli"}
 
@@ -409,10 +419,11 @@ def info(
     release_time = datetime.strptime(urls[-1]["upload_time_iso_8601"], "%Y-%m-%dT%H:%M:%S.%fZ")
     natural_time = release_time.strftime("%b %d, %Y")
     description = info["summary"]
-    latest_version = list(sorted(releases.keys(), key=LooseVersion, reverse=True))[0]
+    latest_version = list(sorted(map(parse_version, releases.keys()), reverse=True))[0]
+    latest_stable_version = list(sorted(map(parse_version, releases.keys()), reverse=True))[0]
     version_comment = (
         "[green]Latest Version[/]"
-        if latest_version == info["version"]
+        if str(latest_version) == str(info["version"])
         else f"[red]Newer version available ({latest_version})[/]"
     )
     repo = re.findall(
@@ -578,6 +589,41 @@ def regex_search(
             console.print("[yellow]There are more than 50 matches, consider using the --compact flag")
 
 
+@app.command()
+def browse(package_name: str = Argument(...)):
+    """Browse for a package's URLs"""
+    url = f"https://pypi.org/pypi/{quote(package_name)}/json"
+    with console.status("Getting data from PyPI"):
+        response = requests.get(url, headers=headers)
+
+    if response.status_code != 200:
+        if response.status_code == 404:
+            rich.print("[red]Project not found[/]")
+        rich.print(f"[orange]Some error occured. response code {response.status_code}[/]")
+        raise typer.Exit()
+
+    parsed_data = json.loads(response.text)
+    info = parsed_data["info"]
+
+    urls = info["project_urls"]
+    urls["Project URL"] = info.get("project_url")
+    urls["Home Page"] = info.get("project_url")
+    urls["Release URL"] = info.get("release_url")
+    urls["Mail to"] = ("mailto:" + info["maintainer_email"]) if info.get("maintainer_email") else None
+
+    answer = questionary.select(
+        "Which link do you want to to open?",
+        choices=[
+            questionary.Choice(title=[("class:name", name), ("class:seperator", " - "), ("class:url", url)], value=url)
+            for name, url in urls.items()
+            if url
+        ],
+        style=link_style,
+    ).ask()
+    if answer:
+        webbrowser.open(answer)
+
+
 def run():
     """Run the CLI."""
     app()
